# This scripts generates the plots used in the paper.
#
#
# The first thing we need to do is to clear the memory and load the necessary
# R libraries.
rm (list = ls())
library(reshape2)
library(ggplot2)

library(gtable)
library(grid)

#library(gridExtra)

#library(cowplot)


# Figures 2,3,4 ________________________________________________________________
#
#
# Loading and collating the results files:
files <- list.files("./output/")
files <- files[23:42]#files[1:20]

df <- data.frame()
for (file in files){
  print(paste("loading batteries from file:", file))
  load(paste0("./output/",file))
  for(i in batteries){
    df<-rbind(df,i)
  }
}

# Removing unused variables:
#names(df)
a <- df[,-c(1,2,3,4,6,7,8,9,14)]

# We transform this variable in order to be able to plot it on a log scale
a$reviewingExpenses[a$reviewingExpenses <= 0] <- 0.001





#_______________________________________________________________________________
# Homogeneous vs heterogeneous grade language (by # categories)
#
#
#
#
plotScenario <- function (scenario, ar, sig.position=rep(1,times=5)) {
  plotVar <- function(
    d, var, varLabel, xLabel, miny = NA, maxy = NA, p.valuePosition = 1,
    legendPosition = "none"
  ) {
    
    b = d
    es <- c(5, 10, 20)
    
    if(is.na(miny)){miny <- min(b[,var])}
    if(is.na(maxy)){maxy <- max(b[,var])}
    if(miny=="bottomWhisker"){
      # top boxplot hinge (75th percentile) + (IQR * 1.5)
      miny <- unname(quantile(b[,var], 0.25)) - (IQR(b[,var]) * 1.5)
    }
    if(maxy=="topWhisker"){
      # top boxplot hinge (75th percentile) + (IQR * 1.5)
      maxy <- unname(quantile(b[,var], 0.75)) + (IQR(b[,var]) * 1.5)
    }
    if(is.na(xLabel)){xLabel <- "# categories"}
    
    
    findSig <- function(d, varx, vary, evaluationScale){
      df <- d[d$evaluationScale == evaluationScale,]
      #d <- subset(d, as.character(d$evaluationScale) == evaluationScale)
      groups <- as.character(unique(df[,varx]))
      a <- df[df[,varx] == groups[1], vary]
      b <- df[df[,varx] == groups[2], vary]
      
      p <- t.test(
        a, b, var.equal = FALSE
      )$p.value
      
      sig <- "n.s."
      if (p <= 0.05) {sig <- "*"}
      if (p <= 0.01) {sig <- "**"}
      if (p <= 0.001) {sig <- "***"}
      
      return(sig)
    }
    #findSig(a, "gradeLanguage", var, 20)
    
    sigMarkers <- c(
      findSig(b, "gradeLanguage", var, es[1]),
      findSig(b, "gradeLanguage", var, es[2]),
      findSig(b, "gradeLanguage", var, es[3])
    )
    
    sigPositions <- c(
      unname(quantile(b[b$evaluationScale == es[1],var], 0.93)),
      unname(quantile(b[b$evaluationScale == es[2],var], 0.93)),
      unname(quantile(b[b$evaluationScale == es[3],var], 0.93))
    )
    sigPositions <- sigPositions * p.valuePosition
    
    
    return(ggplot(
      b,
      aes(x=b$evaluationScale, y=b[,var], fill=b$gradeLanguage)
      #aes(x=b$gradeLanguage, y=b$value, group=b$evaluationScale)
    ) +
      geom_boxplot(color="#00000077", outlier.size = 0.5) +
      #, outlier.shape = ".") +#NA) +
      #scale_y_continuous(trans = "log2") +
      scale_fill_manual(
        labels = c("homogeneous\ngrade language","heterogeneous\ngrade language"),
        values = c("gray70", "darkorange1")
      ) +
      coord_cartesian(ylim = c(miny, maxy)) +
      annotate("text", x=1, y=sigPositions[1], label=sigMarkers[1]) +
      annotate("text", x=2, y=sigPositions[2], label=sigMarkers[2]) +
      annotate("text", x=3, y=sigPositions[3], label=sigMarkers[3]) +
      ylab(varLabel) + xlab(xLabel) +
      #"gold", "darkorange", "firebrick1", "gray80", "gray60", "gray40"))) +
      #ylim(c(0,30))
      theme(
        plot.title = element_text(hjust = 0.5),
        legend.position = legendPosition,
        legend.title = element_blank(),
        legend.key.width = unit(12, 'pt'),
        legend.key.height = unit(40, 'pt'),
        legend.background = element_blank(),
        legend.key = element_rect(fill = alpha("white", 0.0)), ###
        legend.box.background = element_blank(),
        panel.border = element_blank(),
        
        panel.grid.major.x = element_blank(),
        panel.grid.minor = element_blank(),
        axis.line.x = element_line(colour = "black"),
        #axis.title = element_blank(),
        #axis.text.x = element_text(angle = 60, hjust = 1),
        strip.text.y = element_text(angle=0, hjust = 0),
        strip.background.y = element_blank()
      ))
  }
  
  p1 <- plotVar(
    d = a[a$SGscenario == scenario & a$acceptanceRate == ar,],
    var="evaluationBias", varLabel = "evaluation error", xLabel = "",
    miny="bottomWhisker", maxy = "topWhisker", p.valuePosition=sig.position[1]
  ) + ggtitle(paste("scenario:", scenario))
  p2 <- plotVar(
    a[a$SGscenario == scenario & a$acceptanceRate == ar,],
    var="resourceLoss", varLabel = "resource loss", xLabel = "",
    miny="bottomWhisker", maxy = "topWhisker", p.valuePosition=sig.position[2]
  )
  p3 <- plotVar(
    a[a$SGscenario == scenario & a$acceptanceRate == ar,],
    var="reviewingExpenses", varLabel = "reviewing expenses", xLabel = "",
    miny="bottomWhisker", maxy = "topWhisker", p.valuePosition=sig.position[3]
  )
  p4 <- plotVar(
    a[a$SGscenario == scenario & a$acceptanceRate == ar,],
    var="systemProductivity", varLabel = "system productivity", xLabel = "",
    miny="bottomWhisker",# maxy = "topWhisker"
    p.valuePosition=sig.position[4]
  )
  p5 <- plotVar(
    a[a$SGscenario == scenario & a$acceptanceRate == ar,],
    var="giniIndex", varLabel = "Gini index", xLabel = NA,legendPosition = "bottom",
    miny="bottomWhisker",# maxy = "topWhisker"
    p.valuePosition=sig.position[5]
  )
  #legend <- get_legend(plotVar(
  #  d = a[a$SGscenario == scenario & a$acceptanceRate == ar,],
  #  var="evaluationBias", varLabel = "evaluation error", xLabel = "",
  #  miny="bottomWhisker", maxy = "topWhisker", legendPosition = "left"
  #))
  
  
  g1 <- ggplotGrob(p1)
  g2 <- ggplotGrob(p2)
  g3 <- ggplotGrob(p3)
  g4 <- ggplotGrob(p4)
  g5 <- ggplotGrob(p5)
  g <- rbind(g1, g2, g3, g4, g5, size = "first")
  gmain <- rbind(g1, g2, g5, size = "first")
  
  g$widths <- unit.pmax(g1$widths, g2$widths, g3$widths, g4$widths, g5$widths)
  gmain$widths <- unit.pmax(g1$widths, g2$widths, g5$widths)
  
  return(g)
  #return(gmain)
}

#scenario = "no reciprocity"
#scenario = "fairness"
#scenario = "fair authors"
#scenario = "indirect reciprocity"
#ar = 0.5

scenarios <- c(
  "no reciprocity",
  "indirect reciprocity",
  "fairness",
  "self-interested authors",
  "fair authors"
)
sig.positions <- list(
  c(1,1.05,1.05,1.05,1.05),
  c(1,1,1,1,1),
  c(1,1,1,1.05,1),
  c(1,1,1,1.03,1),
  c(1,1,0.5,23,1)
)

for(i in 1:length(scenarios)){
  png(
    filename = paste0("./outputGraphics/nCategories - ", scenarios[i], ".png"),
    width = 800,
    height = 2000,
    units = "px",
    res = 240
  )
  grid.newpage()
  grid.draw(plotScenario(
    scenario = scenarios[i],
    ar = 0.5,
    sig.position = sig.positions[[i]]
  ))
  dev.off()
}


# The following is for plotting a subset of the measures in the plots above.
# Specifically, the following only plots some of the outcome measures for only
# two scenarios.
# This is the code used to create figures 3, 4.
if(FALSE){ ###
  
  scenariosmain <- c(
  "no reciprocity",
  "fairness"
)
#sig.positionsMain <- list(
#  c(1,1.05,1.05),
#  c(1,1,1)
#)
for(i in 1:length(scenariosmain)){
  png(
    filename = paste0("./outputGraphics/mainNCategories - ", scenariosmain[i], ".png"),
    width = 800,
    height = 1400,
    units = "px",
    res = 240
  )
  grid.newpage()
  grid.draw(plotScenario(
    scenario = scenariosmain[i],
    ar = 0.5,
    sig.position = sig.positions[[i]]
  ))
  dev.off()
}

} #### 


#_______________________________________________________________________________
# Which scenario performs best
# (acceptance rate and # categories are kept constant)
#
#
#
#
compareScenarios <- function(data, var, varLabel){
  b <- data
  
  minvar <- max(c(0, min(b[,var])))
  ifelse(
    var %in% c("reviewingExpenses", "systemProductivity"),
    maxvar <- unname(quantile(b[,var], 0.97)),
    maxvar <- max(b[,var])
  )
  
  p <- ggplot(
    b,
    aes(
      x=b$SGscenario,
      y=b[,var],
      
      # Note that we fiddle to with the levels in order to show homogeneous GL
      # first. We'll flip the legend key labels and the colors accordingly so that
      # the boxplots' grade language is labelled correctly and consistently.
      fill=factor(b$gradeLanguage, levels=rev(levels(b$gradeLanguage))))
  ) +
    geom_boxplot(color="#00000077", outlier.size = 0.5) +# outlier.shape = NA) +
    scale_fill_manual(
      labels = rev(c("homogeneous\ngrade language","heterogeneous\ngrade language")),
      values = rev(c("gray70", "darkorange1"))
    ) +
    guides(fill = guide_legend(reverse=TRUE)) +
    coord_flip(ylim = c(minvar, maxvar)) +
    scale_x_discrete(limits = rev(levels(b$SGscenario))) +
    #coord_cartesian(ylim = c(minvar, maxvar)) +
    ylab(varLabel) +
    theme(
      legend.title = element_blank(),
      legend.key = element_rect(fill = "white", colour = "white"),
      legend.position = "right",
      legend.key.width = unit(12, 'pt'),
      legend.key.height = unit(40, 'pt'),
      legend.background = element_blank(),
      legend.box.background = element_blank(),
      panel.border = element_blank(),
      panel.background = element_rect(fill="gray97"),
      panel.grid.major.y = element_line(colour = "gray85"),#"gray90"
      panel.grid.major.x = element_blank(),
      panel.grid.minor = element_blank(),
      axis.line.x = element_line(colour = "black"),
      axis.title.y = element_blank()
    )
  ifelse(
    var == "systemProductivity",
    return(p + theme(axis.text.x= element_text(angle = 45, hjust = 1))),
    return(p)
  )
}

# Selecting a "baseline" configuration
ar = 0.5
b=a[a$acceptanceRate == ar & a$evaluationScale == 5,]

# Plotting a plot for each outcome variable
vars = c(
  "evaluationBias",
  "resourceLoss",
  "reviewingExpenses",
  "systemProductivity",
  "giniIndex"
)
varLabels = c(
  "evaluation error",
  "resource loss",
  "reviewing expenses",
  "system productivity",
  "Gini index"
)
for (i in 1:length(vars)){
  png(
    filename = paste0("./outputGraphics/scenarios - ", vars[i], ".png"),
    width = 800,
    height = 400,
    units = "px",
    res = 180
  )
  print(compareScenarios(b,vars[i],varLabels[i]))
  dev.off()
}




#_______________________________________________________________________________
# Comparing acceptance rates
# (acceptance rate and # categories are kept constant)
#
#
#
#
plotScenario <- function (scenario, nCat=5, sig.position=rep(1,times=5)){
  
  plotVar <- function(
    d, var, varLabel, xLabel=NA, miny = NA, maxy = NA, p.valuePosition = 1,
    legendPosition = "none"
  ) {
    b = d#[d$evaluationScale == nCategories,]
    #es <- c(5, 10, 20)
    ar <- rev(c(0.25, 0.5, 0.75))
    
    if(is.na(miny)){miny <- max(c(min(b[,var]), 0))}
    if(is.na(maxy)){maxy <- max(b[,var])}
    if(miny=="bottomWhisker"){
      # top boxplot hinge (75th percentile) + (IQR * 1.5)
      miny <- unname(quantile(b[,var], 0.25)) - (IQR(b[,var]) * 1.5)
    }
    if(maxy=="topWhisker"){
      # top boxplot hinge (75th percentile) + (IQR * 1.5)
      maxy <- unname(quantile(b[,var], 0.75)) + (IQR(b[,var]) * 1.5)
    }
    if(is.na(xLabel)){xLabel <- "acceptance rate"}
    
    
    findSig <- function(d, varx, vary, acceptanceRate){
      df <- d[d$acceptanceRate == acceptanceRate,]
      #d <- subset(d, as.character(d$evaluationScale) == evaluationScale)
      groups <- as.character(unique(df[,varx]))
      a <- df[df[,varx] == groups[1], vary]
      b <- df[df[,varx] == groups[2], vary]
      
      p <- t.test(
        a, b, var.equal = FALSE
      )$p.value
      
      sig <- "n.s."
      if (p <= 0.05) {sig <- "*"}
      if (p <= 0.01) {sig <- "**"}
      if (p <= 0.001) {sig <- "***"}
      
      return(sig)
    }
    #findSig(a, "gradeLanguage", var, 20)
      
    sigMarkers <- c(
      findSig(b, "gradeLanguage", var, ar[1]),
      findSig(b, "gradeLanguage", var, ar[2]),
      findSig(b, "gradeLanguage", var, ar[3])
    )
    
    sigPositions <- c(
      unname(quantile(b[b$acceptanceRate == ar[1],var], 0.93)),
      unname(quantile(b[b$acceptanceRate == ar[2],var], 0.93)),
      unname(quantile(b[b$acceptanceRate == ar[3],var], 0.93))
    )
    
    if (scenario == "fair authors" & var == "reviewingExpenses")
    {sigPositions <- rep (70, times=3)}
    
    sigPositions <- sigPositions * p.valuePosition
    
    
    return(ggplot(
      b,
      aes(x=b$acceptanceRate, y=b[,var], fill=b$gradeLanguage)
      #aes(x=b$gradeLanguage, y=b$value, group=b$evaluationScale)
    ) +
      geom_boxplot(color="#00000077", outlier.size = 0.5) +
      #, outlier.shape = ".") +#NA) +
      #scale_y_continuous(trans = "log2") +
      scale_fill_manual(
        labels = c("homogeneous\ngrade language","heterogeneous\ngrade language"),
        values = c("gray70", "darkorange1")
      ) +
      coord_cartesian(ylim = c(miny, maxy)) +
      annotate("text", x=1, y=sigPositions[1], label=sigMarkers[1]) +
      annotate("text", x=2, y=sigPositions[2], label=sigMarkers[2]) +
      annotate("text", x=3, y=sigPositions[3], label=sigMarkers[3]) +
      ylab(varLabel) + xlab(xLabel) +
      #"gold", "darkorange", "firebrick1", "gray80", "gray60", "gray40"))) +
      #ylim(c(0,30))
      theme(
        plot.title = element_text(hjust = 0.5),
        legend.position = legendPosition,
        legend.title = element_blank(),
        legend.key.width = unit(12, 'pt'),
        legend.key.height = unit(40, 'pt'),
        legend.background = element_blank(),
        legend.key = element_rect(fill = alpha("white", 0.0)), ###
        legend.box.background = element_blank(),
        panel.border = element_blank(),
        
        panel.grid.major.x = element_blank(),
        panel.grid.minor = element_blank(),
        axis.line.x = element_line(colour = "black"),
        #axis.title = element_blank(),
        #axis.text.x = element_text(angle = 60, hjust = 1),
        strip.text.y = element_text(angle=0, hjust = 0),
        strip.background.y = element_blank()
      ))
  }
  
  p1 <- plotVar(
    d = a[a$SGscenario == scenario & a$evaluationScale == nCat,],
    var="evaluationBias", varLabel = "evaluation error", xLabel = "",
    #miny="bottomWhisker",
    maxy = "topWhisker", p.valuePosition=sig.position[1]
  ) + ggtitle(paste("scenario:", scenario))
  p2 <- plotVar(
    a[a$SGscenario == scenario & a$evaluationScale == nCat,],
    var="resourceLoss", varLabel = "resource loss", xLabel = "",
    #miny="bottomWhisker",
    maxy = "topWhisker", p.valuePosition=sig.position[2]
  )
  
  p3 <- plotVar(
    a[a$SGscenario == scenario & a$evaluationScale == nCat,],
    var="reviewingExpenses", varLabel = "reviewing expenses", xLabel = "",
    #miny="bottomWhisker",
    maxy = "topWhisker", p.valuePosition = sig.position[3]
  )
  p4 <- plotVar(
    a[a$SGscenario == scenario & a$evaluationScale == nCat,],
    var="systemProductivity", varLabel = "system productivity", xLabel = "",
    #miny="bottomWhisker",# maxy = "topWhisker"
    p.valuePosition=sig.position[4]
  )
  p5 <- plotVar(
    a[a$SGscenario == scenario & a$evaluationScale == nCat,],
    var="giniIndex", varLabel = "Gini index", xLabel = NA,
    legendPosition = "bottom",
    #miny="bottomWhisker",# maxy = "topWhisker"
    p.valuePosition=sig.position[5]
  )
  #legend <- get_legend(plotVar(
  #  d = a[a$SGscenario == scenario & a$acceptanceRate == ar,],
  #  var="evaluationBias", varLabel = "evaluation error", xLabel = "",
  #  miny="bottomWhisker", maxy = "topWhisker", legendPosition = "left"
  #))
  
  
  g1 <- ggplotGrob(p1)
  g2 <- ggplotGrob(p2)
  g3 <- ggplotGrob(p3)
  g4 <- ggplotGrob(p4)
  g5 <- ggplotGrob(p5)
  g <- rbind(g1, g2, g3, g4, g5, size = "first")
  g$widths <- unit.pmax(g1$widths, g2$widths, g3$widths, g4$widths, g5$widths)
  
  return(g)
}

#scenario = "no reciprocity"
#scenario = "fairness"
#scenario = "fair authors"
#scenario = "indirect reciprocity"
#ar = 0.5

scenarios <- c(
  "no reciprocity",
  "indirect reciprocity",
  "fairness",
  "self-interested authors",
  "fair authors"
)
sig.positions <- list(
  c(1,1.05,1.05,1.05,1.05),
  c(1,1,1.05,1.05,1.03),
  c(1,1,1,1.05,1),
  c(1,1,0.95,1.05,1.05),
  c(1,1,1,20,1)
)

for(i in 1:length(scenarios)){
  png(
    filename = paste0("./outputGraphics/accept.rate - ", scenarios[i], ".png"),
    width = 800,
    height = 2000,
    units = "px",
    res = 240
  )
  grid.newpage()
  grid.draw(plotScenario(
    scenario = scenarios[i],
    nCat = 5,
    sig.position = sig.positions[[i]]
  ))
  dev.off()
}








  

# Figure 1 _____________________________________________________________________
#
#
# Plotting figure 1 (which shows examples of thresholds)
source("util.r")
criteria <- cbind.data.frame(
  c("q1"), # name of the criterion
  c("beta"), # Underlying true quality distribution
  c(3),       # alpha (parameter in the beta distribution)
  c(3),       # beta  (parameter in the beta distribution)
  c(5),         # scale (expressed as number of categories)
  c("random"), # Grade language
  c(1), # gradeLanguageHeterogeneity
  c(1)          # relative weight of the criteria 
)
names(criteria) <- c("name", "distribution", "alpha", "beta", "scale", 
                     "gradeLanguage", "gradeLanguageHeterogeneity", "weights")


d <- data.frame(c("scholar A", "scholar B"))
names(d) <- "id"
gl <- createGradeLanguage(d, criteria)
d <- cbind(d, as.data.frame(matrix(rbind(gl[[1]], gl[[2]]), nrow=2)))
d$init <- c(0,0)
d$fin <- c(1,1)

d$id <- as.factor(d$id)
levels(d$id) <- rev(levels(d$id))
col = "darkorange1"
cl = "gray40"
pointer="I"
labz = c(
  "very negative\n","negative\n","neutral\n","positive\n","very positive\n")
ps = 20
ls = 3

png(
  filename = "./outputGraphics/SG2013_gradeLangExample.png",
  width = 800,
  height = 300,
  units = "px",
  #pointsize = 40#,
  res = 150
)
ggplot(
  d,
  aes(y=id)
) +
  geom_text(aes(x=V1, y=id, color=col, label=pointer, size=ps)) +
  geom_text(aes(x=V2, y=id, color=col, label=pointer, size=ps)) +
  geom_text(aes(x=V3, y=id, color=col, label=pointer, size=ps)) +
  geom_text(aes(x=V4, y=id, color=col, label=pointer, size=ps)) +
  geom_text(aes(x=init, y=id, label=pointer, size=ps)) +
  geom_text(aes(x=fin, y=id, label=pointer, size=ps)) +
  geom_text(aes(x=V1/2, y=id, label=labz[1]),color=cl,check_overlap=TRUE, size=ls) +
  geom_text(aes(x=(V2-V1)/2+V1, y=id, label=labz[2]),color=cl,check_overlap=TRUE, size=ls) +
  geom_text(aes(x=(V3-V2)/2+V2, y=id, label=labz[3]),color=cl,check_overlap=TRUE, size=ls) +
  geom_text(aes(x=(V4-V3)/2+V3, y=id, label=labz[4]),color=cl,check_overlap=TRUE, size=ls) +
  geom_text(aes(x=(1-V4)/2+V4, y=id, label=labz[5]),color=cl,check_overlap=TRUE, size=ls) +
  #xlim(c(0,1)) + #scale_y_discrete(trans="reverse") +
  xlab("\nevaluation scale") +
  scale_x_continuous(limits=c(-0.001,1), expand=c(0,0), breaks=c(0:5/5)) +
  #labs(xlab="test") +
  theme(
    legend.position = "none",
    panel.border = element_blank(),
    panel.background = element_blank(),
    panel.grid.major.y = element_line(color="black"),
    panel.grid.major.x = element_line(color="gray95"),
    panel.grid.minor = element_blank(),
    axis.ticks.y = element_blank(),
    axis.line = element_blank(),
    axis.title.y = element_blank()
  )
dev.off()




# Figure 2 _____________________________________________________________________
#
#
# Plotting figure 2 which shows the distribution of thresholds in case of
# heterogeneous grade language.
rm(list=ls())
library(ggplot2)
library(Cairo) # for anti-aliasing
library(reshape2)
source("util.r")

criteria <- cbind.data.frame(
  name = c("q1"), # name of the criterion
  distribution = c("beta"), # Underlying true quality distribution
  alpha = c(3),       # alpha (parameter in the beta distribution)
  beta = c(3),       # beta  (parameter in the beta distribution)
  scale = c(5),         # scale (expressed as number of categories)
  gradeLanguage = c("random"), # Grade language
  gradeLanguageHeterogeneity = c(1), # gradeLanguageHeterogeneity
  weights = c(1)          # relative weight of the criteria 
)
scholars <- data.frame(id=c(1:1000000))

# Creating list containing all reviewers' GL trhesholds:
x <- createGradeLanguage(scholars = scholars, criterion = criteria)

# Converting the list to a matrix for easy plotting:
d <- matrix(unlist(x), ncol=4, byrow=TRUE)
rm(x)
d <- as.data.frame(d)
names(d) <- c(
  "1st threshold\nbetween very neg. and neg.",
  "2nd threshold\nbetween neg. and neutral",
  "3rd threshold\nbetween neutral and pos.",
  "4th threshold\nbetween pos. and very pos."
)
d <- reshape2::melt(d)

# And plotting.
png(
  filename = "./outputGraphics/SG2013_thresholds distribution.png",
  width = 800,
  height = 400,
  units = "px",
  #pointsize = 40#,
  res = 150,
  type="cairo" # for anti-aliasing, which is a concern for geom_violin on
               # Windows machines.
)
ggplot(d, aes(x = variable, y = value)) +
  geom_violin(
    fill = "gray20",
    #color = "white",
    #adjust = 1,
    draw_quantiles = c(0.25, 0.5, 0.75)
  ) +
  #geom_violin( color="black",draw_quantiles = c(0.25, 0.5, 0.75)) +
  stat_summary(
    fun.y = mean, fun.ymin = mean, fun.ymax = mean,
    #fun.y=median,
    geom="crossbar",
    width = 0.5, size=0.25, color="darkorange1"
  ) +
  ylab("evaluation scale") +
  scale_y_continuous(breaks = c(0, 0.2, 0.4, 0.6, 0.8, 1)) +
  coord_flip() + scale_x_discrete(limits = rev(levels(d$variable))) +
  theme(
    legend.position = "none",
    panel.border = element_blank(),
    panel.background = element_blank(),
    panel.grid.major.x = element_line(color="gray95"),
    panel.grid.major.y = element_blank(),#element_line(color="gray95"),
    panel.grid.minor = element_blank(),
    axis.ticks.y = element_blank(),
    axis.line = element_blank(),
    axis.title.y = element_blank()
  )
dev.off()







outcomes <- c(
  "giniIndex",
  "evaluationBias",
  "resourceLoss",
  "reviewingExpenses",
  "systemProductivity"
)

for (ar in unique(df$acceptanceRate))
for (sc in unique(df$SGscenario))
for (out in outcomes) 
for (cat in c(5,10,20))
{
  print(paste("acceptance rate", ar, "- scenario:", sc))
  a1 <- subset(
    df,
    df$evaluationScale==cat &
      df$acceptanceRate==ar &
      df$SGscenario==sc &
      df$gradeLanguage=="none"
    )[,out]
  a2 <- subset(
    df,
    df$evaluationScale==cat &
      df$acceptanceRate==ar &
      df$SGscenario==sc &
      df$gradeLanguage=="random"
    )[,out]
  tt <- t.test (a1, a2)
  
  stars <- function(p){
    stars <- "non-significant"
    if (p <= 0.05) {stars <- "*"}
    if (p <= 0.01) {stars <- "**"}
    if (p <= 0.001) {stars <- "***"}
    return(stars)
  }
  print(paste(
    out, "with", cat, "categories:", stars(tt$p.value)
  ))
}



