# Cleaning up, loading resources and setting a random seed
#rm (list = ls( )) 
source("abm.r")

# This makes r compile functions on first execution.
library(compiler)
enableJIT(1)

bat<-1
for (bat in 1:22){
  parameterSpace = expand.grid(
    initialAgentRsrc = c("even"),                    #Initial Agent Resource Distribution
    acceptanceRate = c(0.75,0.5,0.25),                       #Acceptance Rate
    evaluationBias = c(0.1),                        #Evaluation Bias by Default
    sdSubmQuality = c(0.1),                        #SD submission Quality
    scenarios =c(
      "no reciprocity",                     #Scenarios
      "indirect reciprocity",
      "fairness",
      "self-interested authors",
      "fair authors"),
    timestamp = c(200),                                 #Timestamp
    gradeLanguage = c("none", "random"),               #Grade Language
    evaluationScale = c(5, 10, 20)
  )
  
  # We specify how many times we want to run a parameter configuration. Each run
  # will have a different random seed.
  nRunsPerCondition <- 5
  
  #Output dataframe
  
  #Execution
  countSimRun <- 1
  batteries = list()
  for(i in 1:nrow(parameterSpace)){
    temp = data.frame() # To store results with same parameter space
    for(r in 1:nRunsPerCondition){
      seed <- sample.int(999999999, size = 1)
      print(paste(
        "Starting simulation ",
        countSimRun,
        "of",
        nrow(parameterSpace) * nRunsPerCondition
      ))
      print(paste("Battery run:", bat, "Seed:", seed, "- Parameter index:", i))
      print(paste("Timestamp:", Sys.time()))
      
      results <- replicateSG2013(
        seed = seed,  
        numberOfAgents = 200,
        initialAgentResources = as.character(parameterSpace$initialAgentRsrc[i]),
        acceptanceRate = parameterSpace$acceptanceRate[i],
        SGbaselineEvaluationBias = parameterSpace$evaluationBias[i],
        sdSubmissionQuality = parameterSpace$sdSubmQuality[i],
        timeSteps = parameterSpace$timestamp[i],
        SGscenario = as.character(parameterSpace$scenarios[i]),
        gradeLanguage = as.character(parameterSpace$gradeLanguage[i]),
        evaluationScale = parameterSpace$evaluationScale[i],
        exportTimeSeries = FALSE,            #Result for only the last run
        printTimeStamp = FALSE
      )
      temp = rbind(temp, results[[1]])      #Append the results to temp; Store only the result from last run 
      countSimRun <- countSimRun+1
    }
    batteries[[i]] = temp # Store the Results for same parameters as a DataFrame to a list
  }
  
  
  save(
    parameterSpace,
    batteries,
    file=paste0("./output/SG2013_results_20200204_",bat , ".RData")
  )
  
  bat <- bat+1
}

enableJIT(0)